@@ -25,7 +25,7 @@ static struct ip6t_policy_info *policy_info;
 static void policy_help(void)
 {
 	printf(
-"policy v%s options:\n"
+"policy match options:\n"
 "  --dir in|out			match policy applied during decapsulation/\n"
 "				policy to be applied during encapsulation\n"
 "  --pol none|ipsec		match policy\n"
@@ -37,8 +37,7 @@ static void policy_help(void)
 "[!] --mode mode 		match mode (transport/tunnel)\n"
 "[!] --tunnel-src addr/masklen	match tunnel source\n"
 "[!] --tunnel-dst addr/masklen	match tunnel destination\n"
-"  --next 			begin next element in policy\n",
-	IPTABLES_VERSION);
+"  --next 			begin next element in policy\n");
 }
 
 static const struct option policy_opts[] =
@@ -91,7 +90,7 @@ static const struct option policy_opts[] =
 		.name		= "next",
 		.val		= 'a'
 	},
-	{ }
+	{ .name = NULL }
 };
 
 /* FIXME - Duplicated code from ip6tables.c */
@@ -126,13 +125,6 @@ mask_to_numeric(const struct in6_addr *addrp)
 	return buf;
 }
 
-/* These should be in include/ip6tables.h... */
-extern u_int16_t parse_protocol(const char *s);
-extern void parse_hostnetworkmask(const char *name, struct in6_addr **addrpp,
-		struct in6_addr *maskp, unsigned int *naddrs);
-
-/* End duplicated code from ip6tables.c */
-
 static int parse_direction(char *s)
 {
 	if (strcmp(s, "in") == 0)
@@ -223,7 +215,7 @@ static int policy_parse(int c, char **argv, int invert, unsigned int *flags,
 			exit_error(PARAMETER_PROBLEM,
 			           "policy match: double --tunnel-src option");
 
-		parse_hostnetworkmask(argv[optind-1], &addr, &mask, &naddr);
+		ip6parse_hostnetworkmask(argv[optind-1], &addr, &mask, &naddr);
 		if (naddr > 1)
 			exit_error(PARAMETER_PROBLEM,
 			           "policy match: name resolves to multiple IPs");
@@ -238,7 +230,7 @@ static int policy_parse(int c, char **argv, int invert, unsigned int *flags,
 			exit_error(PARAMETER_PROBLEM,
 			           "policy match: double --tunnel-dst option");
 
-		parse_hostnetworkmask(argv[optind-1], &addr, &mask, &naddr);
+		ip6parse_hostnetworkmask(argv[optind-1], &addr, &mask, &naddr);
 		if (naddr > 1)
 			exit_error(PARAMETER_PROBLEM,
 			           "policy match: name resolves to multiple IPs");
@@ -450,11 +442,12 @@ static void policy_save(const void *ip, const struct xt_entry_match *match)
 	}
 }
 
-static struct ip6tables_match policy_match6 = {
+static struct xtables_match policy_mt6_reg = {
 	.name		= "policy",
-	.version	= IPTABLES_VERSION,
-	.size		= IP6T_ALIGN(sizeof(struct ip6t_policy_info)),
-	.userspacesize	= IP6T_ALIGN(sizeof(struct ip6t_policy_info)),
+	.version	= XTABLES_VERSION,
+	.family		= PF_INET6,
+	.size		= XT_ALIGN(sizeof(struct ip6t_policy_info)),
+	.userspacesize	= XT_ALIGN(sizeof(struct ip6t_policy_info)),
 	.help		= policy_help,
 	.parse		= policy_parse,
 	.final_check	= policy_check,
@@ -465,5 +458,5 @@ static struct ip6tables_match policy_match6 = {
 
 void _init(void)
 {
-	register_match6(&policy_match6);
+	xtables_register_match(&policy_mt6_reg);
 }
