@@ -9,19 +9,17 @@
 #include <linux/netfilter_ipv4/ipt_ah.h>
                                         
 /* Function which prints out usage message. */
-static void
-help(void)
+static void ah_help(void)
 {
 	printf(
-"AH v%s options:\n"
+"ah match options:\n"
 " --ahspi [!] spi[:spi]\n"
-"				match spi (range)\n",
-NETFILTER_VERSION);
+"				match spi (range)\n");
 }
 
-static struct option opts[] = {
-	{ "ahspi", 1, 0, '1' },
-	{0}
+static const struct option ah_opts[] = {
+	{ "ahspi", 1, NULL, '1' },
+	{ .name = NULL }
 };
 
 static u_int32_t
@@ -67,8 +65,7 @@ parse_ah_spis(const char *spistring, u_int32_t *spis)
 }
 
 /* Initialize the match. */
-static void
-init(struct ipt_entry_match *m, unsigned int *nfcache)
+static void ah_init(struct xt_entry_match *m)
 {
 	struct ipt_ah *ahinfo = (struct ipt_ah *)m->data;
 
@@ -79,11 +76,8 @@ init(struct ipt_entry_match *m, unsigned int *nfcache)
 
 /* Function which parses command options; returns true if it
    ate an option */
-static int
-parse(int c, char **argv, int invert, unsigned int *flags,
-      const struct ipt_entry *entry,
-      unsigned int *nfcache,
-      struct ipt_entry_match **match)
+static int ah_parse(int c, char **argv, int invert, unsigned int *flags,
+                    const void *entry, struct xt_entry_match **match)
 {
 	struct ipt_ah *ahinfo = (struct ipt_ah *)(*match)->data;
 
@@ -91,9 +85,8 @@ parse(int c, char **argv, int invert, unsigned int *flags,
 	case '1':
 		if (*flags & AH_SPI)
 			exit_error(PARAMETER_PROBLEM,
-				   "Only one `--spi' allowed");
-		if (check_inverse(optarg, &invert))
-			optind++;
+				   "Only one `--ahspi' allowed");
+		check_inverse(optarg, &invert, &optind, 0);
 		parse_ah_spis(argv[optind-1], ahinfo->spis);
 		if (invert)
 			ahinfo->invflags |= IPT_AH_INV_SPI;
@@ -106,12 +99,6 @@ parse(int c, char **argv, int invert, unsigned int *flags,
 	return 1;
 }
 
-/* Final check; we don't care. */
-static void
-final_check(unsigned int flags)
-{
-}
-
 static void
 print_spis(const char *name, u_int32_t min, u_int32_t max,
 	    int invert)
@@ -134,9 +121,8 @@ print_spis(const char *name, u_int32_t min, u_int32_t max,
 }
 
 /* Prints out the union ipt_matchinfo. */
-static void
-print(const struct ipt_ip *ip,
-      const struct ipt_entry_match *match, int numeric)
+static void ah_print(const void *ip, const struct xt_entry_match *match,
+                     int numeric)
 {
 	const struct ipt_ah *ah = (struct ipt_ah *)match->data;
 
@@ -149,43 +135,42 @@ print(const struct ipt_ip *ip,
 }
 
 /* Saves the union ipt_matchinfo in parsable form to stdout. */
-static void save(const struct ipt_ip *ip, const struct ipt_entry_match *match)
+static void ah_save(const void *ip, const struct xt_entry_match *match)
 {
 	const struct ipt_ah *ahinfo = (struct ipt_ah *)match->data;
 
-	if (ahinfo->spis[0] != 0
-	    && ahinfo->spis[1] != 0xFFFFFFFF) {
-		if (ahinfo->invflags & IPT_AH_INV_SPI)
-			printf("! ");
+	if (!(ahinfo->spis[0] == 0
+	    && ahinfo->spis[1] == 0xFFFFFFFF)) {
+		printf("--ahspi %s", 
+			(ahinfo->invflags & IPT_AH_INV_SPI) ? "! " : "");
 		if (ahinfo->spis[0]
 		    != ahinfo->spis[1])
-			printf("--spi %u-%u ",
+			printf("%u:%u ",
 			       ahinfo->spis[0],
 			       ahinfo->spis[1]);
 		else
-			printf("--spi %u ",
+			printf("%u ",
 			       ahinfo->spis[0]);
 	}
 
 }
 
-struct iptables_match ah
-= { NULL,
-    "ah",
-    NETFILTER_VERSION,
-    IPT_ALIGN(sizeof(struct ipt_ah)),
-    IPT_ALIGN(sizeof(struct ipt_ah)),
-    &help,
-    &init,
-    &parse,
-    &final_check,
-    &print,
-    &save,
-    opts
+static struct xtables_match ah_mt_reg = {
+	.name 		= "ah",
+	.version 	= XTABLES_VERSION,
+	.family		= PF_INET,
+	.size		= XT_ALIGN(sizeof(struct ipt_ah)),
+	.userspacesize 	= XT_ALIGN(sizeof(struct ipt_ah)),
+	.help 		= ah_help,
+	.init 		= ah_init,
+	.parse 		= ah_parse,
+	.print 		= ah_print,
+	.save 		= ah_save,
+	.extra_opts 	= ah_opts,
 };
 
 void
 _init(void)
 {
-	register_match(&ah);
+	xtables_register_match(&ah_mt_reg);
 }
